@@ -3,6 +3,7 @@ import os
 
 # Import third party libs
 from cryptography.fernet import Fernet
+from dict_tools import utils
 import yaml
 import msgpack
 
@@ -49,4 +50,5 @@ def data_decrypt(hub, fn, key):
     f = Fernet(key)
     with open(fn, "rb") as rfh:
         raw = f.decrypt(rfh.read())
-    return msgpack.loads(raw)
+    ret = msgpack.loads(raw)
+    return utils.decode_dict(ret)
