@@ -1,3 +1,6 @@
+import asyncio
+
+
 def __init__(hub):
     # Remember not to start your app in the __init__ function
     # This function should just be used to set up the plugin subsystem
@@ -23,6 +26,16 @@ def unlock(hub, fn, key):
     """
     hub.acct.SUB_PROFILES = {}
     hub.acct.PROFILES = hub.acct.enc.data_decrypt(fn, key)
+
+    # If a profile has credentials for an external profile backend, unlock it now
+    for backend, kwargs in hub.acct.PROFILES.get("acct-backend", {}).items():
+        if hasattr(hub, f"acct.{backend}"):
+            plug = getattr(hub, f"acct.{backend}")
+            if "unlock" in plug._funcs:
+                hub.log.trace(f"Unlocking acct backend: acct.{backend}")
+                provider_data = plug.unlock(**kwargs)
+                hub.pop.dicts.update(hub.acct.PROFILES, provider_data)
+
     if "default" in hub.acct.PROFILES:
         hub.acct.DEFAULT = hub.acct.PROFILES
     else:
@@ -49,7 +62,9 @@ async def gather(hub, subs, profile):
         for plug in getattr(hub, f"acct.{sub}"):
             hub.log.trace(f"Gathering account information for '{sub}.{plug.__name__}'")
             if "gather" in plug._funcs:
-                p_data = await plug.gather() or {}
+                p_data = plug.gather() or {}
+                if asyncio.iscoroutine(p_data):
+                    p_data = await p_data
                 hub.pop.dicts.update(sub_data, p_data)
         hub.acct.SUB_PROFILES[sub] = sub_data
     for sub, sub_data in hub.acct.SUB_PROFILES.items():
